==> phobos-framework-0.5.11.jar: framework/systemApps/startup.js <==
/*
 * The contents of this file are subject to the terms 
 * of the Common Development and Distribution License 
 * (the License).  You may not use this file except in
 * compliance with the License.
 * 
 * You can obtain a copy of the license at 
 * https://glassfish.dev.java.net/public/CDDLv1.0.html or
 * glassfish/bootstrap/legal/CDDLv1.0.txt.
 * See the License for the specific language governing 
 * permissions and limitations under the License.
 * 
 * When distributing Covered Code, include this CDDL 
 * Header Notice in each file and include the License file 
 * at glassfish/bootstrap/legal/CDDLv1.0.txt.  
 * If applicable, add the following below the CDDL Header, 
 * with the fields enclosed by brackets [] replaced by
 * you own identifying information: 
 * "Portions Copyrighted [year] [name of copyright owner]"
 * 
 * Copyright 2006 Sun Microsystems, Inc. All rights reserved.
 */

// configuration of system apps

(function() {
    application.path.controller.push({element: "/framework/systemApps/controller", prefix: "system"});
    application.path.module.push({element: "/framework/systemApps/module", prefix: "system"});
    application.path.view.push({element: "/framework/systemApps/view", prefix: "system"});
    application.path.content.push({element: "/framework/systemApps/static", prefix: "system"});

    var rules = application.mapping.defaultRules.low;
    if (rules == undefined) {
        application.mapping.defaultRules.low = rules = [];
    }
    rules.push({ url: "/system/@controller/@action",
                 fn: "library.mapping.maybeController",
                 prefix: "system" });
    rules.push({ url: "/system/@controller/",
                 defaults: {action: "index"},
                 fn: "library.mapping.maybeController",
                 prefix: "system" });
    rules.push({ url: "/system/@controller",
                 defaults: {action: "index"},
                 fn: "library.mapping.maybeController",
                 prefix: "system" });                         
    rules.push({ url: "/system/",
                 defaults: {controller: "main", action: "index"},
                 fn: "library.mapping.maybeController",
                 prefix: "system" });                         
})();

==> phobos-framework-0.5.13.jar: framework/systemApps/startup.js <==
/*
 * The contents of this file are subject to the terms 
 * of the Common Development and Distribution License 
 * (the License).  You may not use this file except in
 * compliance with the License.
 * 
 * You can obtain a copy of the license at 
 * https://glassfish.dev.java.net/public/CDDLv1.0.html or
 * glassfish/bootstrap/legal/CDDLv1.0.txt.
 * See the License for the specific language governing 
 * permissions and limitations under the License.
 * 
 * When distributing Covered Code, include this CDDL 
 * Header Notice in each file and include the License file 
 * at glassfish/bootstrap/legal/CDDLv1.0.txt.  
 * If applicable, add the following below the CDDL Header, 
 * with the fields enclosed by brackets [] replaced by
 * you own identifying information: 
 * "Portions Copyrighted [year] [name of copyright owner]"
 * 
 * Copyright 2006 Sun Microsystems, Inc. All rights reserved.
 */

// configuration of system apps

(function() {
    application.path.controller.push({element: "/framework/systemApps/controller", prefix: "system"});
    application.path.module.push({element: "/framework/systemApps/module", prefix: "system"});
    application.path.view.push({element: "/framework/systemApps/view", prefix: "system"});
    application.path.content.push({element: "/framework/systemApps/static", prefix: "system"});

    var rules = application.mapping.defaultRules.low;
    if (rules == undefined) {
        application.mapping.defaultRules.low = rules = [];
    }
    rules.push({ url: "/system/@controller/@action",
                 fn: "library.mapping.maybeController",
                 prefix: "system" });
    rules.push({ url: "/system/@controller/",
                 defaults: {action: "index"},
                 fn: "library.mapping.maybeController",
                 prefix: "system" });
    rules.push({ url: "/system/@controller",
                 defaults: {action: "index"},
                 fn: "library.mapping.maybeController",
                 prefix: "system" });                         
    rules.push({ url: "/system/",
                 defaults: {controller: "main", action: "index"},
                 fn: "library.mapping.maybeController",
                 prefix: "system" });
    rules.push({ url: "/system/docgen/browse/@uuid=((\\w|-)+)@tail=((/((\\w|-)*(\\.?\\w*))+)+)",
                 defaults: {controller: "docgen", action: "browse"},
                 fn: "library.mapping.maybeController",
                 prefix: "system" });
})();
